pub trait UtcDurationExt {
// Required method
fn to_boot_lossy(&self) -> Duration<BootTimeline>;
}Expand description
Special methods that are only valid for UtcDuration.
Required Methods
Sourcefn to_boot_lossy(&self) -> Duration<BootTimeline>
fn to_boot_lossy(&self) -> Duration<BootTimeline>
Converts the reading of a duration on the UTC timeline to a reading on the boot timeline.
This is “lossy” because durations are usually differences of two Instants, and Boot time and UTC time mostly tick at the same rate. However, they aren’t required to tick in lock-step.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".